@@ -7,7 +7,7 @@ use Carp;
 
 use base 'Devel::Timer';
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 my $telemetry = __PACKAGE__->new();
 
@@ -26,7 +26,7 @@ sub import {
 
     my $caller = caller();
 
-    no strict 'refs';    ## no critic (TestingAndDebugging::ProhibitNoStrict
+    no strict 'refs';    ## no critic (TestingAndDebugging::ProhibitNoStrict)
     my $varname = "${caller}::${saw_var}";
     *$varname = \$telemetry;
 
